=== modified file 'bzrlib/smart/medium.py'
--- bzrlib/smart/medium.py	2009-12-11 21:57:03 +0000
+++ bzrlib/smart/medium.py	2009-12-18 22:14:18 +0000
@@ -300,7 +300,10 @@
         tstart = osutils.timer_func()
         osutils.send_all(self.socket, bytes, self._report_activity)
         if 'hpss' in debug.debug_flags:
-            thread_id = threading.currentThread().ident
+            cur_thread = threading.currentThread()
+            thread_id = getattr(cur_thread, 'ident', None)
+            if thread_id is None:
+                thread_id = cur_thread.getName()
             trace.mutter('%12s: [%s] %d bytes to the socket in %.3fs'
                          % ('wrote', thread_id, len(bytes),
                             osutils.timer_func() - tstart))

=== modified file 'bzrlib/smart/protocol.py'
--- bzrlib/smart/protocol.py	2009-12-16 18:11:26 +0000
+++ bzrlib/smart/protocol.py	2009-12-18 22:14:18 +0000
@@ -1147,7 +1147,12 @@
         self.response_sent = False
         self._headers = {'Software version': bzrlib.__version__}
         if 'hpss' in debug.debug_flags:
-            self._thread_id = threading.currentThread().get_ident()
+            # python 2.6 introduced 'ident' as a nice small integer to
+            # represent a thread. But it doesn't exist in 2.4/2.5
+            cur_thread = threading.currentThread()
+            self._thread_id = getattr(cur_thread, 'ident', None)
+            if self._thread_id is None:
+                self._thread_id = cur_thread.getName()
             self._response_start_time = None
 
     def _trace(self, action, message, extra_bytes=None, include_time=False):

=== modified file 'bzrlib/smart/request.py'
--- bzrlib/smart/request.py	2009-12-14 16:16:05 +0000
+++ bzrlib/smart/request.py	2009-12-18 22:14:18 +0000
@@ -291,7 +291,10 @@
         self._command = None
         if 'hpss' in debug.debug_flags:
             self._request_start_time = osutils.timer_func()
-            self._thread_id = threading.currentThread().get_ident()
+            cur_thread = threading.currentThread()
+            self._thread_id = getattr(cur_thread, 'ident', None)
+            if self._thread_id is None:
+                self._thread_id = cur_thread.getName()
 
     def _trace(self, action, message, extra_bytes=None, include_time=False):
         # It is a bit of a shame that this functionality overlaps with that of 

=== modified file 'bzrlib/tests/blackbox/test_serve.py'
--- bzrlib/tests/blackbox/test_serve.py	2009-11-25 13:21:52 +0000
+++ bzrlib/tests/blackbox/test_serve.py	2009-12-18 21:54:54 +0000
@@ -27,6 +27,7 @@
 
 from bzrlib import (
     builtins,
+    debug,
     errors,
     osutils,
     revision as _mod_revision,
@@ -45,6 +46,7 @@
 from bzrlib.trace import mutter
 from bzrlib.transport import get_transport, remote
 
+
 class TestBzrServeBase(TestCaseWithTransport):
 
     def run_bzr_serve_then_func(self, serve_args, retcode=0, func=None,
@@ -130,7 +132,9 @@
             finish_bzr_subprocess, a client for the server, and a transport.
         """
         # Serve from the current directory
-        process = self.start_bzr_subprocess(['serve', '--inet'])
+        args = ['serve', '--inet']
+        args.extend(extra_options)
+        process = self.start_bzr_subprocess(args)
 
         # Connect to the server
         # We use this url because while this is no valid URL to connect to this
@@ -180,9 +184,10 @@
 
         process, transport = self.start_server_inet(['--allow-writes'])
 
-        # We get a working branch
+        # We get a working branch, and can create a directory
         branch = BzrDir.open_from_transport(transport).open_branch()
         self.make_read_requests(branch)
+        transport.mkdir('adir')
         self.assertInetServerShutsdownCleanly(process)
 
     def test_bzr_serve_port_readonly(self):
@@ -215,6 +220,21 @@
         self.make_read_requests(branch)
         self.assertServerFinishesCleanly(process)
 
+    def test_bzr_serve_dhpss(self):
+        # This is a smoke test that the server doesn't crash when run with
+        # -Dhpss, and does drop some hpss logging to the file.
+        self.make_branch('.')
+        log_fname = os.getcwd() + '/server.log'
+        self._captureVar('BZR_LOG', log_fname)
+        process, transport = self.start_server_inet(['-Dhpss'])
+        branch = BzrDir.open_from_transport(transport).open_branch()
+        self.make_read_requests(branch)
+        self.assertInetServerShutsdownCleanly(process)
+        f = open(log_fname, 'rb')
+        content = f.read()
+        f.close()
+        self.assertContainsRe(content, 'hpss request: \[')
+
 
 class TestCmdServeChrooting(TestBzrServeBase):
 

